Index: chrome/browser/net/net_log_temp_file.h |
diff --git a/chrome/browser/net/net_log_temp_file.h b/chrome/browser/net/net_log_temp_file.h |
index 2b96276449587ababa206f0be90018a979b11c30..0ea28ab066a6ee4801aff207f0580b7382dc03eb 100644 |
--- a/chrome/browser/net/net_log_temp_file.h |
+++ b/chrome/browser/net/net_log_temp_file.h |
@@ -151,9 +151,9 @@ class NetLogTempFile { |
base::FilePath log_path_; // base::FilePath to the temporary file. |
- // |net_log_logger_| watches the NetLog event stream, and sends all entries to |
- // the file created in StartNetLog(). |
- scoped_ptr<net::WriteToFileNetLogObserver> net_log_logger_; |
+ // |write_to_file_observer_| watches the NetLog event stream, and |
+ // sends all entries to the file created in StartNetLog(). |
+ scoped_ptr<net::WriteToFileNetLogObserver> write_to_file_observer_; |
// The |chrome_net_log_| is owned by the browser process, cached here to avoid |
// using global (g_browser_process). |